@@ -18,7 +18,7 @@
 
 #include <pthread.h>
 
-#include "bionic_macros.h"
+#include "platform/bionic/macros.h"
 
 class ScopedPthreadMutexLocker {
  public:
