@@ -34,9 +34,9 @@
 #include <sys/cdefs.h>
 #include <sys/param.h>
 
-#include "bionic_asm_tls.h"
-#include "bionic_macros.h"
-#include "__get_tls.h"
+#include <platform/bionic/tls.h>
+
+#include "platform/bionic/macros.h"
 #include "grp_pwd.h"
 
 /** WARNING WARNING WARNING
@@ -128,6 +128,9 @@ struct bionic_tls {
   group_state_t group;
   passwd_state_t passwd;
 
+  char fdtrack_disabled;
+  char padding[3];
+
   // Initialize the main thread's final object using its bootstrap object.
   void copy_from_bootstrap(const bionic_tls* boot __attribute__((unused))) {
     // Nothing in bionic_tls needs to be preserved in the transition to the
